## This spec is based on kolab's spec from the OBS

%define _disable_ld_no_undefined 1

# major is the part of the library name after the .so
%define major 0
%define libname %mklibname %{name} %{major}
%define develname %mklibname %{name} -d


%global with_systemd 1

%global _name cyrus-imapd

%global ssl_pem_file %{_sysconfdir}/pki/%{_name}/%{_name}.pem


%global _cyrususer cyrus
%global _cyrusgroup mail
%global _cyrexecdir %{_exec_prefix}/lib/%{_name}

%global real_version 2.5.11

##
## Options
##

%global with_bdb        1
%global with_mysql      1
%global with_pgsql      1

%global with_dav        0
%global with_tcpwrap    1

Name:               cyrus-imapd
Summary:            A high-performance mail server with IMAP, POP3, NNTP and SIEVE support
Version:            %{real_version}
Release:            %mkrel 1
License:            BSD
Group:              System/Servers
URL:                http://www.cyrusimap.org

# Upstream sources
Source0:            ftp://ftp.cyrusimap.org/cyrus-imapd/%{_name}-%{real_version}.tar.gz
Source1:            cyrus-imapd.imap-2.5.x-conf
Source2:            cyrus-imapd.cvt_cyrusdb_all
Source3:            cyrus-imapd.magic

# Distribution specific sources
Source11:           cyrus-imapd.logrotate
Source12:           cyrus-imapd.pam-config
Source13:           cyrus-imapd.cron-daily

# SysVinit
Source22:           cyrus-imapd.sysconfig


# Systemd support
Source31:           cyrus-imapd.service
Source32:           cyr_systemd_helper

##
## Patches
##

Provides:           imap
Provides:           imap-server

##
## Build Requirements
##
BuildRequires:      autoconf
BuildRequires:      automake
BuildRequires:      bison
BuildRequires:      pkgconfig(libsasl2)
BuildRequires:      pkgconfig(cunit)
BuildRequires:      sasl-plug-digestmd5
BuildRequires:      sasl-plug-plain
BuildRequires:      pkgconfig(libxml-2.0)

%if 0%{?with_bdb}
BuildRequires:      db5-devel
%endif
BuildRequires:      flex
#BuildRequires:     gcc-c++
BuildRequires:      gcc
BuildRequires:      groff
BuildRequires:      pkgconfig(jansson)
BuildRequires:      pkgconfig(krb5)

%if 0%{?with_dav}
BuildRequires:      pkgconfig(libical)
%endif

BuildRequires:      libtool
BuildRequires:      pkgconfig(uuid)

%if 0%{?with_mysql}
BuildRequires:      mysql-devel
%endif
BuildRequires:      openldap-devel
BuildRequires:      openssl-devel
BuildRequires:      perl(ExtUtils::MakeMaker)

BuildRequires:      perl-devel
BuildRequires:      pkgconfig

%if 0%{?with_pgsql}
BuildRequires:      postgresql-devel
%endif

%if 0%{?with_dav}
BuildRequires:      pkgconfig(sqlite3)
%endif

%if 0%{?with_tcpwrap}
BuildRequires:      tcp_wrappers
%endif

BuildRequires:      transfig
%if 0
# Disable the xapian-core requirement
BuildRequires:      xapian-core-devel
%endif

Requires:           db5-utils
Requires:           file
## Spuhler 2016-01-22: I don't think we need this (Fedora has it in the perl-libs pacakge
#Requires:           perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))
Requires(post):     coreutils
Requires(post):     e2fsprogs
Requires(post):     findutils
Requires(post):     grep
Requires(post):     make
Requires(post):     openssl
Requires(post):     perl
Requires(preun):    coreutils
Requires(pre):      /usr/sbin/useradd /usr/sbin/groupadd
Requires(preun):    /usr/sbin/userdel /usr/sbin/groupdel
Requires(post):     rpm-helper >= 0.24.8-1
Requires(preun):    rpm-helper >= 0.24.8-1


Obsoletes:          %{name}-perl < %{version}-%{release}
Provides:           %{name}-perl = %{version}-%{release}
Obsoletes:          %{name}-utils < %{version}-%{release}
Provides:           %{name}-utils = %{version}-%{release}

%description
The %{name} package contains the core of the Cyrus IMAP server.
It is a scaleable enterprise mail system designed for use from
small to large enterprise environments using standards-based
internet mail technologies.

A full Cyrus IMAP implementation allows a seamless mail and bulletin
board environment to be set up across multiple servers. It differs from
other IMAP server implementations in that it is run on "sealed"
servers, where users are not normally permitted to log in and have no
system account on the server. The mailbox database is stored in parts
of the filesystem that are private to the Cyrus IMAP server. All user
access to mail is through software using the IMAP, POP3 or KPOP
protocols. It also includes support for virtual domains, NNTP,
mailbox annotations, and much more. The private mailbox database design
gives the server large advantages in efficiency, scalability and
administratability. Multiple concurrent read/write connections to the
same mailbox are permitted. The server supports access control lists on
mailboxes and storage quotas on mailbox hierarchies.

The Cyrus IMAP server supports the IMAP4rev1 protocol described
in RFC 3501. IMAP4rev1 has been approved as a proposed standard.
It supports any authentication mechanism available from the SASL
library, imaps/pop3s/nntps (IMAP/POP3/NNTP encrypted using SSL and
TLSv1) can be used for security. The server supports single instance
store where possible when an email message is addressed to multiple
recipients, SIEVE provides server side email filtering.

%package -n     %{libname}
Summary:        Cyrus IMAP server library files
Group:          System/Libraries
 
%description -n %{libname}
The %{name}-lib package contains the library for cyrus-imapd

%package -n     %{develname}
Summary:        Cyrus IMAP server development files
Group:          Development/Other
Requires:       %{libname} = %{version}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
The %{name}-devel package contains header files and libraries
necessary for developing applications which use the imclient library.


%package -n	perl-Cyrus
Summary:	Cyrus IMAPd utility Perl modules
Group:		Development/Perl

%description -n	perl-Cyrus
This package contains Perl modules necessary to use the Cyrus server
administrative utilities.

The main package is %{name}.

%prep
%setup -q -n %{_name}-%{real_version}%{?dot_snapshot_version}

%if 0%{?with_bdb} < 1
sed -i -e 's/,berkeley//g' cunit/db.testc
sed -r -i -e 's/"berkeley(|-[a-z-]+)", //g' lib/imapoptions
%endif

# only to update config.* files
autoreconf -vi || (libtoolize --force && autoreconf -vi)

# Modify docs master --> cyrus-master
%{__perl} -pi -e "s@master\(8\)@cyrus-master(8)@" man/*5 man/*8 lib/imapoptions
%{__sed} -i -e 's|\([^-]\)master|\1cyrus-master|g;s|^master|cyrus-master|g;s|Master|Cyrus-master|g;s|MASTER|CYRUS-MASTER|g' \
        man/master.8 doc/man.html

%if 0%{?with_dav}
# Modify docs httpd --> cyrus-httpd
%{__perl} -pi -e "s@httpd\(8\)@cyrus-httpd(8)@" man/*5 man/*8 lib/imapoptions
%{__sed} -i -e 's|\([^-]\)httpd|\1cyrus-httpd|g;s|^httpd|cyrus-httpd|g;s|Httpd|Cyrus-httpd|g;s|HTTPD|CYRUS-HTTPD|g' \
        man/httpd.8 doc/man.html
%endif

# Modify path in perl scripts
find . -type f -name "*.pl" | xargs %{__perl} -pi -e "s@/usr/local/bin/perl@%{__perl}@"

# modify lmtp socket path in .conf files
%{__perl} -pi -e "s@/var/imap/@%{_var}/lib/imap/@" master/conf/*.conf doc/cyrusv2.mc doc/m4/%{name}-sendmail-8.12.9-cyrusv2.m4

# enable idled in .conf files to prevent error messages
%{__perl} -pi -e "s/#  idled/  idled/" master/conf/*.conf

%build
CPPFLAGS="-I%{_includedir}/et -I%{_includedir}/kerberosIV"
export CPPFLAGS
CFLAGS="$RPM_OPT_FLAGS -fPIC"
export CFLAGS
CXXFLAGS="$RPM_OPT_FLAGS -fPIC"; 
export CXXFLAGS
CCDLFLAGS="-rdynamic"
export CCDLFLAGS
LDFLAGS="-L%{_libdir}"
export LDFLAGS

%configure2_5x \
    --enable-event-notification \
    --enable-gssapi \
    --enable-idled \
    --enable-murder \
    --enable-netscapehack \
    --enable-nntp \
    --enable-replication \
    --enable-unit-tests \
%if 0
    --enable-xapian \
%endif
%if 0%{?with_bdb}
    --with-bdb-incdir=%{_includedir}/db4 \
%else
    --without-bdb \
%endif
    --with-cyrus-prefix=%{_cyrexecdir} \
    --with-extraident="Kolab-%{version}-%{release}" \
%if 0%{?with_tcpwrap} < 1
    --without-wrap \
%endif
%if 0%{?with_dav}
    --enable-http \
%endif
    --with-krbimpl=mit \
    --with-ldap=/usr \
%if 0%{?with_mysql}
    --with-mysql=%{_prefix} \
    --with-mysql-incdir=%{_includedir}/mysql/ \
    --with-mysql \
%endif
    --with-perl=%{__perl} \
%if 0%{?with_pgsql}
    --with-pgsql=%{_includedir} \
%endif
    --with-service-path=%{_cyrexecdir} \
    --with-syslogfacility=MAIL

%make

%install


# Fix permissions on perl programs
find . -type f -name "*.pl" -exec %{__chmod} 755 {} \;

# Do what the regular make install does
%{__make} install DESTDIR=%{buildroot} PREFIX=%{_prefix} mandir=%{_mandir} INSTALLDIRS=vendor

# Install tools
for tool in tools/* ; do
  test -f ${tool} && %{__install} -m 755 ${tool} %{buildroot}%{_cyrexecdir}/
done

# Create directories
%{__install} -d \
  %{buildroot}%{_sysconfdir}/{logrotate.d,pam.d,cron.daily} \
  %{buildroot}%{_libdir}/sasl \
  %{buildroot}%{_var}/spool/imap \
  %{buildroot}%{_var}/lib/imap/{user,quota,proc,log,msg,socket,db,sieve,sync,md5,rpm,backup,meta} \
  %{buildroot}%{_var}/lib/imap/ptclient \
  %{buildroot}%{_sysconfdir}/pki/%{_name} \
  doc/contrib

# Install additional files
%{__install} -p -m 644 master/conf/prefork.conf %{buildroot}%{_sysconfdir}/cyrus.conf
%{__install} -p -m 644 %{SOURCE1}    %{buildroot}%{_sysconfdir}/imapd.conf
%{__install} -p -m 755 %{SOURCE2}   %{buildroot}%{_cyrexecdir}/cvt_cyrusdb_all
%{__install} -p -m 644 %{SOURCE3}   %{buildroot}%{_var}/lib/imap/rpm/magic
%{__install} -p -m 644 %{SOURCE11}    %{buildroot}%{_sysconfdir}/logrotate.d/%{_name}
%{__install} -p -m 644 %{SOURCE12}    %{buildroot}%{_sysconfdir}/pam.d/pop
%{__install} -p -m 644 %{SOURCE12}    %{buildroot}%{_sysconfdir}/pam.d/imap
%{__install} -p -m 644 %{SOURCE12}    %{buildroot}%{_sysconfdir}/pam.d/sieve
%{__install} -p -m 644 %{SOURCE12}    %{buildroot}%{_sysconfdir}/pam.d/mupdate
%{__install} -p -m 644 %{SOURCE12}    %{buildroot}%{_sysconfdir}/pam.d/lmtp
%{__install} -p -m 644 %{SOURCE12}    %{buildroot}%{_sysconfdir}/pam.d/nntp
%{__install} -p -m 644 %{SOURCE12}    %{buildroot}%{_sysconfdir}/pam.d/csync
%{__install} -p -m 755 %{SOURCE13}   %{buildroot}%{_sysconfdir}/cron.daily/%{_name}
%{__install} -d %{buildroot}%{_sysconfdir}/sysconfig/
%{__install} -p -m 644 %{SOURCE22}   %{buildroot}%{_sysconfdir}/sysconfig/%{_name}
%{__install} -p -D -m 644 %{SOURCE31}   %{buildroot}%{_unitdir}/cyrus-imapd.service
%{__install} -p -D -m 755 %{SOURCE32}   %{buildroot}%{_cyrexecdir}/cyr_systemd_helper


# Cleanup of doc dir
find doc perl -name CVS -type d | xargs -r %{__rm} -rf
find doc perl -name .cvsignore -type f | xargs -r %{__rm} -f
%{__rm} -f doc/Makefile.dist*
%{__rm} -f doc/text/htmlstrip.c
%{__rm} -f doc/text/Makefile
%{__rm} -rf doc/man

# fix permissions on perl .so files
find %{buildroot}%{perl_vendorarch} -type f -name "*.so" -exec %{__chmod} 755 {} \;

# fix conflicts with uw-imap
mv %{buildroot}%{_mandir}/man8/imapd.8 %{buildroot}%{_mandir}/man8/imapd.8cyrus
mv %{buildroot}%{_mandir}/man8/pop3d.8 %{buildroot}%{_mandir}/man8/pop3d.8cyrus

# Install templates
%{__install} -m 755 -d doc/conf
%{__install} -m 644 master/conf/*.conf doc/conf/

# Generate db config file
( grep '^{' lib/imapoptions | grep _db | grep -v _db_path | cut -d'"' -f 2,4 | \
  sed -e 's/^ *//' -e 's/-nosync//' -e 's/ *$//' -e 's/"/=/'
  echo sieve_version=2.2.3 ) | sort > %{buildroot}%{_var}/lib/imap/rpm/db.cfg

# create the ghost pem file
touch %{buildroot}%{ssl_pem_file}

# Rename 'master' binary and manpage to avoid clash with postfix
%{__mv} -f %{buildroot}%{_cyrexecdir}/master        %{buildroot}%{_cyrexecdir}/cyrus-master
%{__mv} -f %{buildroot}%{_mandir}/man8/master.8     %{buildroot}%{_mandir}/man8/cyrus-master.8

# Rename 'httpd' binary and manpage to avoid clash with apache httpd
%if 0%{?with_dav}
%{__mv} -f %{buildroot}%{_cyrexecdir}/httpd         %{buildroot}%{_cyrexecdir}/cyrus-httpd
%{__mv} -f %{buildroot}%{_mandir}/man8/httpd.8      %{buildroot}%{_mandir}/man8/cyrus-httpd.8
%endif

# Rename 'fetchnews' binary and manpage to avoid clash with leafnode
%{__mv} -f %{buildroot}%{_cyrexecdir}/fetchnews     %{buildroot}%{_cyrexecdir}/cyrfetchnews
%{__mv} -f %{buildroot}%{_mandir}/man8/fetchnews.8  %{buildroot}%{_mandir}/man8/cyrfetchnews.8
%{__perl} -pi -e 's|fetchnews|cyrfetchnews|g;s|Fetchnews|Cyrfetchnews|g;s/FETCHNEWS/CYRFETCHNEWS/g' \
        %{buildroot}%{_mandir}/man8/cyrfetchnews.8

# compress manpages
[ -x /usr/lib/rpm/brp-compress ] && /usr/lib/rpm/brp-compress

# remove executable bit from docs
for ddir in doc perl/imap/examples
do
  find $ddir -type f -exec %{__chmod} -x {} \;
done

# Remove installed but not packaged files
%{__rm} -f %{buildroot}%{_cyrexecdir}/htmlstrip.c
%{__rm} -f %{buildroot}%{_cyrexecdir}/not-mkdep
%{__rm} -f %{buildroot}%{_cyrexecdir}/config2header*
%{__rm} -f %{buildroot}%{_cyrexecdir}/config2man
%{__rm} -f %{buildroot}%{_cyrexecdir}/pop3proxyd
find %{buildroot} -type f -name "perllocal.pod" -exec %{__rm} -vf {} \;
find %{buildroot} -type f -name ".packlist" -exec %{__rm} -vf {} \;
find %{buildroot} -type f -name ".gitignore" -exec %{__rm} -vf {} \;
%{__rm} -f %{buildroot}%{_mandir}/man8/syncnews.8*
find %{buildroot}%{perl_vendorarch} -type f -name "*.bs" -exec %{__rm} -vf {} \;

%check
make check || :


%pre
if [ $1 == 1 ]; then
    # Create 'cyrus' user on target host
    /usr/sbin/groupadd -r saslauth 2> /dev/null || :
    /usr/sbin/useradd -c "Cyrus IMAP Server" -d %{_var}/lib/imap -g %{_cyrusgroup} \
        -G saslauth -s /sbin/nologin -r %{_cyrususer} 2> /dev/null || :
fi

## From documentation:
# It is strongly recommended to shut down the Cyrus IMAP services 
# before performing the upgrade, as the newer binaries will end up 
# writing to mailboxes.db in a way that is not compatible with the older binaries 
# (that would otherwise still be running).
if [ $1 == 2 ]; then
     /usr/bin/systemctl stop cyrus-imapd
fi

%post
CHATTRSYNC=0

if [ -f "%{_sysconfdir}/sysconfig/cyrus-imapd" ]; then
    source %{_sysconfdir}/sysconfig/cyrus-imapd
fi

if [ $CHATTRSYNC -eq 1 ]; then
    # Force synchronous updates of files in the following directories
    chattr -R +S \
        $(grep ^configdirectory: /etc/imapd.conf | cut -d':' -f2) \
        $(grep ^partition- /etc/imapd.conf | cut -d':' -f2) \
        $(grep ^metapartition- /etc/imapd.conf | cut -d':' -f2) 2>/dev/null ||:
fi

# Create SSL certificates
%_create_ssl_certificate cyrus-imapd
chown %{_cyrususer}:%{_cyrusgroup} /etc/pki/tls/private/cyrus-imapd.pem

# These commands may fail in a docker container, which may not
# have a /usr/bin/systemctl with a 'preset' command
%_post_service cyrus-imapd

%preun
%_preun_service cyrus-imapd

%files
%doc COPYING README
%doc doc/*
%config(noreplace) %{_sysconfdir}/cyrus.conf
%config(noreplace) %{_sysconfdir}/imapd.conf
%{_unitdir}/cyrus-imapd.service
%{_cyrexecdir}/cyr_systemd_helper
%dir %{_sysconfdir}/pki
%config(noreplace) %{_sysconfdir}/logrotate.d/%{_name}
%attr(0640,root,%{_cyrusgroup}) %config(noreplace) %{_sysconfdir}/sysconfig/%{_name}
%config(noreplace) %{_sysconfdir}/pam.d/pop
%config(noreplace) %{_sysconfdir}/pam.d/imap
%config(noreplace) %{_sysconfdir}/pam.d/sieve
%config(noreplace) %{_sysconfdir}/pam.d/lmtp
%config(noreplace) %{_sysconfdir}/pam.d/mupdate
%config(noreplace) %{_sysconfdir}/pam.d/csync
%config(noreplace) %{_sysconfdir}/pam.d/nntp
%attr(0755,root,root) %{_bindir}/cyradm
%{_bindir}/imtest
%{_bindir}/installsieve
%{_bindir}/lmtptest
%{_bindir}/mupdatetest
%{_bindir}/nntptest
%{_bindir}/pop3test
%{_bindir}/sieveshell
%{_bindir}/sivtest
%{_bindir}/smtptest
%{_bindir}/synctest
%{_sysconfdir}/cron.daily/%{_name}
%dir %{_cyrexecdir}
%{_cyrexecdir}/arbitron
%{_cyrexecdir}/arbitronsort.pl
%{_cyrexecdir}/chk_cyrus
%{_cyrexecdir}/compile_st.pl
%{_cyrexecdir}/convert-sieve.pl
%{_cyrexecdir}/cyr_deny
%{_cyrexecdir}/cyr_df
%{_cyrexecdir}/cyr_info
#%%{_cyrexecdir}/ctl_conversationsdb
%{_cyrexecdir}/ctl_cyrusdb
%{_cyrexecdir}/ctl_deliver
%{_cyrexecdir}/ctl_mboxlist
#%%{_cyrexecdir}/ctl_zoneinfo
%{_cyrexecdir}/cvt_cyrusdb
%{_cyrexecdir}/cyr_dbtool
%{_cyrexecdir}/cyr_expire
%{_cyrexecdir}/cyr_sequence
%{_cyrexecdir}/cyr_synclog
%{_cyrexecdir}/cyr_userseen
%{_cyrexecdir}/cyrdump
%if 0%{?with_dav}
%{_cyrexecdir}/cyrus-httpd
%{_cyrexecdir}/dav_reconstruct
%{_cyrexecdir}/ctl_zoneinfo
%endif
%{_cyrexecdir}/cyrus-master
%{_cyrexecdir}/deliver
%{_cyrexecdir}/dohash
%{_cyrexecdir}/fixsearchpath.pl
%{_cyrexecdir}/fud
%{_cyrexecdir}/git-version.sh
#%%{_cyrexecdir}/hammer_cyrusdb
%{_cyrexecdir}/imapd
%{_cyrexecdir}/ipurge
%exclude %{_cyrexecdir}/jenkins-build.sh
%{_cyrexecdir}/lmtpd
%{_cyrexecdir}/lmtpproxyd
%{_cyrexecdir}/masssievec
%{_cyrexecdir}/mbexamine
%{_cyrexecdir}/mbpath
%{_cyrexecdir}/mbtool
#%%{_cyrexecdir}/message_test
%{_cyrexecdir}/migrate-metadata
%{_cyrexecdir}/mkimap
%{_cyrexecdir}/mknewsgroups
%{_cyrexecdir}/notifyd
%{_cyrexecdir}/pop3d
%{_cyrexecdir}/quota
%{_cyrexecdir}/reconstruct
%{_cyrexecdir}/rehash
#%%{_cyrexecdir}/search_test
%{_cyrexecdir}/sievec
%{_cyrexecdir}/sieved
%{_cyrexecdir}/smmapd
#%%{_cyrexecdir}/squat_dump
%{_cyrexecdir}/squatter
%{_cyrexecdir}/timsieved
%{_cyrexecdir}/tls_prune
%{_cyrexecdir}/translatesieve
%{_cyrexecdir}/undohash
%{_cyrexecdir}/unexpunge
%{_cyrexecdir}/upgradesieve
%{_cyrexecdir}/cvt_cyrusdb_all
%{_cyrexecdir}/idled
%{_cyrexecdir}/mupdate
%{_cyrexecdir}/mupdate-loadgen.pl
%{_cyrexecdir}/proxyd
%{_cyrexecdir}/sync_client
%{_cyrexecdir}/sync_reset
%{_cyrexecdir}/sync_server
%{_cyrexecdir}/cyrfetchnews
%{_cyrexecdir}/nntpd
%{_cyrexecdir}/ptdump
%{_cyrexecdir}/ptexpire
%{_cyrexecdir}/ptloader
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %dir %{_var}/lib/imap
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %dir %{_var}/lib/imap/backup
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %dir %{_var}/lib/imap/db
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %dir %{_var}/lib/imap/log
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %dir %{_var}/lib/imap/meta
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %dir %{_var}/lib/imap/md5
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %dir %{_var}/lib/imap/msg
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %{_var}/lib/imap/proc
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %{_var}/lib/imap/ptclient
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %dir %{_var}/lib/imap/quota
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %dir %{_var}/lib/imap/rpm
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %dir %{_var}/lib/imap/sieve
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %{_var}/lib/imap/socket
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %dir %{_var}/lib/imap/sync
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %dir %{_var}/lib/imap/user
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %dir %{_var}/spool/imap
%{_libdir}/*.so.*
%{_var}/lib/imap/rpm/*
%doc perl/imap/README
%doc perl/imap/Changes
%doc perl/imap/examples
%dir %{perl_vendorarch}/Cyrus
%dir %{perl_vendorarch}/Cyrus/IMAP
%{perl_vendorarch}/Cyrus/IMAP/Admin.pm
%{perl_vendorarch}/Cyrus/IMAP/Shell.pm
%{perl_vendorarch}/Cyrus/IMAP/IMSP.pm
%{perl_vendorarch}/Cyrus/IMAP.pm
%dir %{perl_vendorarch}/Cyrus/SIEVE
%{perl_vendorarch}/Cyrus/SIEVE/managesieve.pm
%dir %{perl_vendorlib}/Cyrus/
%dir %{perl_vendorlib}/Cyrus/Annotator
%{perl_vendorlib}/Cyrus/Annotator/Daemon.pm
%{perl_vendorlib}/Cyrus/Annotator/Message.pm
%dir %{perl_vendorarch}/auto
%dir %{perl_vendorarch}/auto/Cyrus
%dir %{perl_vendorarch}/auto/Cyrus/IMAP
%{perl_vendorarch}/auto/Cyrus/IMAP/IMAP.so
%dir %{perl_vendorarch}/auto/Cyrus/SIEVE
%dir %{perl_vendorarch}/auto/Cyrus/SIEVE/managesieve
%{perl_vendorarch}/auto/Cyrus/SIEVE/managesieve/managesieve.so
%{_mandir}/man1/*
%{_mandir}/man3/*
%{_mandir}/man5/*
%{_mandir}/man8/*
%dir %{_sysconfdir}/pki/%{_name}
%attr(0640,root,%{_cyrusgroup}) %ghost %config(missingok,noreplace) %verify(not md5 size mtime) %{ssl_pem_file}


%files -n %{libname}
%{_libdir}/*.so.%{major}*

%files -n %{develname}
%defattr(0644,root,root,0755)
%{_includedir}/cyrus
%{_libdir}/pkgconfig/*cyrus*.pc
%{_libdir}/*.so
%{_libdir}/lib*.la

%files -n perl-Cyrus
%doc perl/imap/README perl/imap/Changes perl/imap/examples
%{perl_vendorarch}/auto/Cyrus
%{perl_vendorarch}/Cyrus
%{_mandir}/man3/Cyrus*


%changelog
* Tue May 16 2017 luigiwalser <luigiwalser> 2.5.11-1.mga6
+ Revision: 1102214
- 2.5.11

* Sun Jan 01 2017 luigiwalser <luigiwalser> 2.5.10-1.mga6
+ Revision: 1079128
- 2.5.10

* Sat May 28 2016 spuhler <spuhler> 2.5.8-1.mga6
+ Revision: 1019000
- reversed dav enabled, it doesn't build with current gcc
- upgrade to vers. 2.5.8
  * enabled dav as the build has been fixed upstream

* Thu Apr 28 2016 spuhler <spuhler> 2.5.7-14.mga6
+ Revision: 1007470
- changed create_ssl_certificate to do it the mga way, use the macro

* Wed Mar 23 2016 spuhler <spuhler> 2.5.7-13.mga6
+ Revision: 994690
- rebuild with new arm db53

* Wed Mar 23 2016 spuhler <spuhler> 2.5.7-12.mga6
+ Revision: 994682
- fixed Source numbers
- updated Requires and BuildRequires to db5
  * BS linked ageains db53 anyway

* Tue Mar 22 2016 spuhler <spuhler> 2.5.7-11.mga6
+ Revision: 993851
- fix cyrus-imapd.sysconfig

* Wed Mar 16 2016 luigiwalser <luigiwalser> 2.5.7-10.mga6
+ Revision: 992051
- finish fixing service macros

* Sat Mar 12 2016 spuhler <spuhler> 2.5.7-9.mga6
+ Revision: 989656
- cyrus-imapd.imap-2.3.x-conf upgraded to vers 2.5
- systemd mga macros used

* Fri Mar 11 2016 spuhler <spuhler> 2.5.7-8.mga6
+ Revision: 989315
- fixed systemd file names

* Wed Mar 02 2016 umeabot <umeabot> 2.5.7-7.mga6
+ Revision: 983347
- Rebuild for openssl

* Sun Feb 28 2016 oden <oden> 2.5.7-6.mga6
+ Revision: 980336
- rebuilt for postgresql 9.5.x
- rebuilt for postgresql 9.5.x

* Thu Feb 18 2016 spuhler <spuhler> 2.5.7-5.mga6
+ Revision: 965084
- disabled dav -build as it doesn't build
- stopping the deamon before upgrading (per docu recom)

* Fri Jan 22 2016 spuhler <spuhler> 2.5.7-3.mga6
+ Revision: 926578
- commented out "Requires:perl(:MODULE_COMPAT_%%(eval "`%%{__perl} -V:version`"; echo $version))"
- mageia does not provided it. Fedora has it in the perl-lib package as a provides

* Thu Jan 21 2016 spuhler <spuhler> 2.5.7-2.mga6
+ Revision: 926343
- added BuildRequires:  pkgconfig(sqlite3)
- added BuildRequires: pkgconfig(libxml-2.0)
- bumped rel to make it build
- changed teh libs package the mga way
- some cleanup
- added options
- added define _disable_ld_no_undefined 1 to make it build
- added missing files
- fixed group
- update to vers. 2.5.7
 * first build

* Tue Jan 12 2016 luigiwalser <luigiwalser> 2.4.18-2.mga6
+ Revision: 922204
- add patch from fedora to fix potential overflows
- add patches from opensuse to fix CVE-2015-8077 and CVE-2015-8078

* Sun Sep 27 2015 spuhler <spuhler> 2.4.18-1.mga6
+ Revision: 884294
- removed some commented out macros
  * the still expand with new rpm
- removed patch4 -p1 -b .autosieve.orig
  * the pacakge doesn't build anymore with this patch
  * neither Fedora nor opensuse uses it.
  * The last activity upstream on this: Dec, 22 2009 : Autosieve patch (version 0.6) released for Cyrus IMAPd 2.3.16
- update to vers, 2.4.18
  * This fixes security issue, bug #16823
- and these upstream bugs
  * Security fix: handle urlfetch range starting outside message range
  * A bunch of cleanups and fixes to compiling
  * A bunch of sieve cleanups
  * Enhanced SSL/TLS configuration options
  * Disable use of SSLv2/SSLv3
  * Allow SQL backend for mboxlist and statuscache (thanks Julien Coloos)
  * Fixed Task #116: correct LIST response for domains starting with ?\226?\128?\152inbox.?\226?\128?\153
  * Fixed Task #76: fixed lmtpd userdeny db checks (thanks Leena Heino)
  * Fixed bug #3856: lmtpd now performs userdeny checks
  * Fixed bug #3848: support charset aliases in encoded headers
  * Fixed bug #3853: disconnect_on_vanished_mailbox: release mailbox lock before exiting (thanks Wolfgang Breyha)
  * Fixed bug #3415: fixed nntpd LIST/GROUP bug
  * Fixed bug #3784: no longer crash in THREAD REFERENCES when messages reference themselves
  * Fixed bug #3757: don?\226?\128?\153t segfault on mailbox close with no user

* Thu Jun 25 2015 sander85 <sander85> 2.4.17-21.mga6
+ Revision: 843891
- Rebuild for perl 5.22

* Tue Nov 25 2014 cjw <cjw> 2.4.17-20.mga5
+ Revision: 799124
- rebuild against postgresql9.4

* Wed Oct 15 2014 umeabot <umeabot> 2.4.17-19.mga5
+ Revision: 741977
- Second Mageia 5 Mass Rebuild

* Thu Sep 18 2014 umeabot <umeabot> 2.4.17-18.mga5
+ Revision: 693720
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 2.4.17-17.mga5
+ Revision: 678659
- Mageia 5 Mass Rebuild

* Tue Jun 03 2014 jquelin <jquelin> 2.4.17-16.mga5
+ Revision: 632200
- perl 5.20.0 rebuild

* Sat Mar 22 2014 spuhler <spuhler> 2.4.17-15.mga5
+ Revision: 606561
- idled is need to run. Otherwise we'll see lots of errors
- uncommented the idled line

* Sat Mar 22 2014 spuhler <spuhler> 2.4.17-14.mga5
+ Revision: 606500
- added the conf-chroot.patch file
- activated ptloader (otherwise we get error messages)
- changed /etc/cyrus.conf to make it work with chrooted postfix
- added dir cyrus to /var/spool/postfix/extern/
  * to make it accessible for chrooted postfix (lmtp)
- remove some old kolab-2 stuff

* Sun Mar 16 2014 spuhler <spuhler> 2.4.17-13.mga5
+ Revision: 604056
- removed old kolab related patches
- removed init files
 * we use systemd
- deleted obsoleted cyrus.init file

* Sat Oct 19 2013 umeabot <umeabot> 2.4.17-12.mga4
+ Revision: 533504
- Mageia 4 Mass Rebuild

* Sat Aug 31 2013 fwang <fwang> 2.4.17-11.mga4
+ Revision: 473649
- we now build with libsasl3, which is much higher than 2.1.15

* Sat Aug 31 2013 spuhler <spuhler> 2.4.17-10.mga4
+ Revision: 473615
-rebuild against new cyrus-sasl lib

* Tue Aug 27 2013 luigiwalser <luigiwalser> 2.4.17-9.mga4
+ Revision: 472071
- rebuild for cyrus-sasl

* Wed May 29 2013 fwang <fwang> 2.4.17-8.mga4
+ Revision: 430388
- rebuild for new perl

* Mon May 06 2013 colin <colin> 2.4.17-7.mga3
+ Revision: 412409
- Silence a debug message for user_deny.db (lost when 2.3.16's user_deny_verbosity patch was dropped)

* Thu Apr 18 2013 spuhler <spuhler> 2.4.17-6.mga3
+ Revision: 410430
- added idled command
  corrected the config section so the idle file will actually be built.

* Tue Feb 26 2013 colin <colin> 2.4.17-5.mga3
+ Revision: 400404
- Some packaging fixups after re-enabling many patches
- Update patches for cyrus 2.4.x series
-   o Update the autocreate/autosieve patches for 2.4.x from vx.sk
-   o Disable rmquota patch build (no longer applies in 2.4.x, no update found)
-   o Update plaintext command line patch for 2.4.x
-   o Drop 64bit fixes patch (fixed upstream)
-   o Drop cyradm annotation patch (applied upstream)
-   o Drop string literals patch (fixed upstream)
-   o Drop statuscache verbosity patch (equivalent refactor upstream)
-   o Drop user_deny.db verbosity patch (equivalent refactor upstream)
-   o Drop sync client tls capability patch (fixed upstream)
-   o Drop perl compatibility patch (fixed upstream)
-   o Still disabled: mancyrusdb patch (needs rediff)
-   o Still disabled: md5/sha1 patch (refactored upstream - no longer needed?)

* Sat Feb 02 2013 spuhler <spuhler> 2.4.17-4.mga3
+ Revision: 394129
- in order to prevent to logs filling
  added touch /var/lib/imap/user_deny.db
  added chown cyrus:mail /var/lib/imap/user_deny.db

* Fri Jan 11 2013 umeabot <umeabot> 2.4.17-3.mga3
+ Revision: 348531
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 01 2013 spuhler <spuhler> 2.4.17-2.mga3
+ Revision: 336975
- bumped rel for rebuild
- replaced the obsolete comman 'runuser' with su -c

* Sat Dec 15 2012 spuhler <spuhler> 2.4.17-1.mga3
+ Revision: 331230
- upgrade to 2.4.17
- deleted signature file for version 2.4.16
- added signature file for version 2.4.17

* Tue Jul 31 2012 fwang <fwang> 2.4.16-3.mga3
+ Revision: 276368
- rebuild for db-5.3

* Fri Jul 27 2012 fwang <fwang> 2.4.16-2.mga3
+ Revision: 274848
- build db 5.2

* Sun Jun 10 2012 spuhler <spuhler> 2.4.16-1.mga3
+ Revision: 259168
- ugrade to version 2.4.16

* Thu May 31 2012 jquelin <jquelin> 2.4.13-7.mga3
+ Revision: 252135
- perl 5.16 rebuild

* Sat Apr 28 2012 tmb <tmb> 2.4.13-6.mga2
+ Revision: 233654
- Require rpm-helper >= 0.24.8-1 for systemd support

* Sat Apr 28 2012 tmb <tmb> 2.4.13-5.mga2
+ Revision: 233547
- rebuild for versioned rpm-helper requires

* Mon Apr 23 2012 spuhler <spuhler> 2.4.13-4.mga2
+ Revision: 232749
- added missing cyr_systemd_helper file

* Fri Apr 20 2012 guillomovitch <guillomovitch> 2.4.13-3.mga2
+ Revision: 232094
- sanitize pre/post/preun/postun dependencies
- drop old ssl cert uppgrade procedure
- spec cleanup
- systemd support

* Fri Apr 20 2012 luigiwalser <luigiwalser> 2.4.13-2.mga2
+ Revision: 232025
- s/Mandriva/Mageia/ in ident string

* Thu Jan 26 2012 spuhler <spuhler> 2.4.13-1.mga2
+ Revision: 201745
- upgrade to 2.4.13
  deps
- upgrade to 2.4.13

  + guillomovitch <guillomovitch>
    - rebuild for latest net-snmp

* Mon Jun 13 2011 sander85 <sander85> 2.3.16-5.mga2
+ Revision: 105538
- fix build
- perl 5.14

* Thu Mar 24 2011 dmorgan <dmorgan> 2.3.16-4.mga1
+ Revision: 77107
- Rebuild against new mysql

* Sat Feb 19 2011 spuhler <spuhler> 2.3.16-3.mga1
+ Revision: 54387
- increased rel from 1 to 2 for rebuild with new perl

* Sun Jan 23 2011 ennael <ennael> 2.3.16-2.mga1
+ Revision: 33420
- remove mdkversion
- imported package cyrus-imapd

